OC.L10N.register(
    "groupfolders",
    {
    "Group" : "සමූහය",
    "Read" : "කියවීම",
    "Write" : "ලිවීම",
    "Create" : "සාදන්න",
    "Share" : "බෙදාගන්න",
    "You" : "ඔබ",
    "Remove access rule" : "ප්‍රවේශ නීතිය ඉවත් කරන්න",
    "Select a user or group" : "පරිශීලකයෙකු හෝ සමූහයක් තෝරන්න",
    "Unlimited" : "අසීමිත",
    "Folder name" : "බහාලුමේ නම",
    "Previous" : "පෙර",
    "User" : "පරිශීලක"
},
"nplurals=2; plural=(n != 1);");
